@@ -13,7 +13,7 @@ int doread(int handle,void * buf,ssize_t len, const char * name){
    }
    return 0;
 }
-int dowrite(int handle, const void * buf, ssize_t len,const char *name,const char *name2=""){
+int dowrite(int handle, const void * buf, ssize_t len,const char *name,const char *name2){
    ssize_t i;
    if ((i=write(handle,buf,len))!=len){
       fprintf(stderr,"Error writing %s %s (%i/%i): %s\n",name,name2,i,len,strerror(errno));
@@ -21,7 +21,7 @@ int dowrite(int handle, const void * buf, ssize_t len,const char *name,const cha
    }
    else return 0;
 }
-int doopen(int &handle,const char * name,int access,int mode=0) {
+int doopen(int &handle,const char * name,int access,int mode) {
    if ((handle=open(name,access,mode))==-1){
       fprintf(stderr,"Error opening %s: %s\n",name,strerror(errno));
       return -1;
